@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2005-2007 by Rajko Albrecht                             *
+ *   Copyright (C) 2005-2009 by Rajko Albrecht                             *
  *   ral@alwins-world.de                                                   *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -20,8 +20,8 @@
 #ifndef CCONTEXTLISTENER_H
 #define CCONTEXTLISTENER_H
 
-#include "src/svnqt/context_listener.hpp"
-#include "src/svnqt/smart_pointer.hpp"
+#include "src/svnqt/context_listener.h"
+#include "src/svnqt/smart_pointer.h"
 
 #include <QObject>
 #include <QString>
